@@ -104,6 +104,7 @@ class GetUplinkInfoCommand(CommandWithErrors):
             return ["cxoem", "fabric", "config", "get", "uplink_info", "file",
                     self._params['filename']]
 
+
 class GetMACAddressesCommand(CommandWithErrors):
     """ Describes the cxoem fabric list_macs IPMI command
     """
@@ -181,6 +182,13 @@ class GetIPAddrBase(Command, ResponseParserMixIn):
     def parse_response(self, out, err):
         return out.strip()
 
+class SetIPAddrBase(Command, ResponseParserMixIn):
+    """Describes the ipmitool fabric config set ipaddr_base command"""
+    @property
+    def ipmitool_args(self):
+        return ['cxoem', 'fabric', 'config', 'set', 'ipaddr_base',
+                self._params['ipaddr']]
+
 class GetLinkspeedCommand(Command, ResponseParserMixIn):
     """Describes the ipmitool fabric config get linkspeed command"""
     name = "Get global linkspeed command"
@@ -304,6 +312,18 @@ class GetMACAddressMaskCommand(Command, ResponseParserMixIn):
             raise IpmiError(err)
         return out.strip()
 
+class SetNetmaskCommand(Command, ResponseParserMixIn):
+    @property
+    def ipmitool_args(self):
+        return ['cxoem', 'fabric', 'config', 'set', 'netmask',
+                self._params['netmask']]
+
+class SetDefaultGatewayCommand(Command, ResponseParserMixIn):
+    @property
+    def ipmitool_args(self):
+        return ['cxoem', 'fabric', 'config', 'set', 'defgw',
+                self._params['ipaddr']]
+
 
 fabric_config_commands = {
     "fabric_config_getipinfo"  : GetIPInfoCommand,
@@ -313,6 +333,7 @@ fabric_config_commands = {
     "fabric_config_setipsrc" : SetIPSrcCommand,
     "fabric_config_factory_default" : FactoryDefaultCommand,
     "fabric_config_get_ipaddr_base" : GetIPAddrBase,
+    "fabric_config_set_ipaddr_base" : SetIPAddrBase,
     "fabric_config_getlinkspeed" : GetLinkspeedCommand,
     "fabric_config_setlinkspeed" : SetLinkspeedCommand,
     "fabric_config_getlinkspeedpolicy" : GetLinkspeedPolicyCommand,
@@ -325,5 +346,7 @@ fabric_config_commands = {
     "fabric_config_set_macaddr_base" : SetMACAddressBaseCommand,
     "fabric_config_get_macaddr_base" : GetMACAddressBaseCommand,
     "fabric_config_set_macaddr_mask" : SetMACAddressMaskCommand,
-    "fabric_config_get_macaddr_mask" : GetMACAddressMaskCommand
+    "fabric_config_get_macaddr_mask" : GetMACAddressMaskCommand,
+    "fabric_config_set_netmask": SetNetmaskCommand,
+    "fabric_config_set_defgw": SetDefaultGatewayCommand,
 }
